@@ -10,7 +10,7 @@
 #ABSTRACT: Common methods for App::Cme
 
 package App::Cme::Common;
-$App::Cme::Common::VERSION = '1.014';
+$App::Cme::Common::VERSION = '1.015';
 use strict;
 use warnings;
 use 5.10.1;
@@ -21,6 +21,7 @@ use Pod::POM;
 use Pod::POM::View::Text;
 use Scalar::Util qw/blessed/;
 use Path::Tiny;
+use Encode qw(decode_utf8);
 
 sub cme_global_options {
   my ( $class, $app ) = @_;
@@ -46,9 +47,13 @@ sub cme_global_options {
   );
 }
 
+# modifies $args in place
 sub process_args {
     my ($self, $opt, $args) = @_;
 
+    # see Debian #839593 and perlunicook(1) section X 13
+    @$args = map { decode_utf8($_, 1) } @$args;
+
     my ( $categories, $appli_info, $appli_map ) = Config::Model::Lister::available_models;
     my $application = shift @$args;
 
@@ -224,7 +229,7 @@ App::Cme::Common - Common methods for App::Cme
 
 =head1 VERSION
 
-version 1.014
+version 1.015
 
 =head1 SYNOPSIS
 
